@@ -7,7 +7,6 @@ import datetime
 import smtplib
 from sendgrid import SendGridAPIClient
 from tcw.database import session, init_engine
-from tcw.apps.contest.models import Contest
 from tcw_tasks.utils import expired_contests
 from tcw_tasks.models import Message
 
@@ -34,10 +33,11 @@ def main():
 
 def finish_contests():
     contests = []
+    now = datetime.datetime.utcnow()
 
     try:
         contests = expired_contests()
-        logger.info("%d contests pending closure" % len(contests))
+        logger.info("%d contest(s) pending closure" % len(contests))
     except:
         logger.debug("No contests pending closure")
         return
@@ -47,11 +47,13 @@ def finish_contests():
             if c.attributes is None or 'winners' not in c.attributes:
                 winners = c.pick_winners()
                 c.attributes = {'winners': winners}
-                session.commit()
+                notify_owner(c)
+                logger.info("Owner of contest %s notified of the winners" % (c.name))
+
+            if c.expires < now:
+                logger.info("Closing and removing contest (%s) %s" % (c.name, c.title))
+                session.delete(c)
 
-            notify_owner(c)
-            logger.info("Closing contest (%s) %s" % (c.name, c.title))
-            session.delete(c)
             session.commit()
 
         except Exception as x:
